@@ -1,11 +1,10 @@
 import typing
-from typing import Mapping
 
 from ._base import BaseAdapter
 from .yapf import YapfAdapter
 from .dummy import DummyAdapter
 
-mapping: Mapping[str, BaseAdapter] = {
+mapping = {
     'yapf': YapfAdapter,
     'dummy': DummyAdapter,
 }
